@@ -110,8 +110,8 @@ class GLCanvasImg(wx.glcanvas.GLCanvas):
         tPos[0]*=data.shape[1]
         tPos[1]*=data.shape[0]
         v=tuple(tPos.astype(np.int32))
-        v=tuple(reversed(v))
-        v+=(data[v],)
+        #v=tuple(reversed(v))
+        v+=(data[tuple(reversed(v))],)
         self.SetStatusCB(self.Parent,0,v)
 
         #vS=event.GetPosition()[0]
