@@ -49,7 +49,7 @@ class HdfImageGLFrame(wx.Frame):
       wxAxCtrl.idx=idx
       wxAxCtrlLst.append(wxAxCtrl)
       sizer.Add(wxAxCtrl.sizer, 0, wx.EXPAND | wx.ALIGN_CENTER | wx.ALL, border=5)
-      wxAxCtrl.SetCallback(HdfImageGLFrame.OnSetView,wxAxCtrl)
+      wxAxCtrl.SetCallback(self.OnSetView,wxAxCtrl)
 
     sl=ut.GetSlice(idxXY,ds.shape,wxAxCtrlLst)
     
